#!/usr/local/bin/perl
#
#  This script is an Olympia turn preprocessor which will allow the
# use of symbolic names for items, skills, people, and places, rather
# than the unit ID.
#
# It is written as a filter, reading from stdin and writing to stdout.
# I use it thus:
#
#    parse <turn | mail orders@g1.pbm.com
#
# But then I'm a UNIX user.  You may find other uses. 
# 
# You will probably need to change the first line of this file, since
# perl may live in a different place on your system.
#
# Adding names to the translation table is very simple, just follow
# my lead.  Remember to leave out the comma after the last entry in
# the table.
#
# Created by Jay Gischer
# Date 8/9/94
#

%translation = (
	"gold", "1",
	"peasant", "10",
	"worker", "11",
	"soldier", "12",
	"archer", "13",
	"knight", "14",
	"elite_guard", "15",
	"pikeman", "16",
	"sailor", "19",
	"swordsman", "20",
	"crossbowman", "21",
	"elite_archer", "22",
	"wild_horse", "51",
	"riding_horse", "52",
	"warmount", "53",
	"battering_ram", "60",
	"catapult", "61",
	"siege_tower", "62",
	"yew", "68",
	"elfstone", "69",
	"longbow", "72",
	"plate_armor", "73",
	"longsword", "74",
	"pike", "75",
	"ox", "76",
	"wood", "77",
	"stone", "78",
	"iron", "79",
	"leather", "80",
	"ratspider", "81",
	"blank_scroll", "84",
	"crossbow", "85",
	"rug", "86",
	"fish", "87",
	"spice", "88",
	"pipeweed", "89",
	"ale", "90",
	"wool", "wool",
	"opium", "93",
	"woven_basket", "94",
	"clay_pot", "95",
	"fish_oil", "97",
	"linen", "262",
	"oxen", "76",
        "pitch", "261",
	"beans", "263",
	"Shipcraft", "120",
	"Combat", "121",
	"Stealth", "122",
	"Beastmastery", "123",
	"Persuasion", "124",
	"Construction", "125",
	"Alchemy", "126",
	"Forestry", "128",
	"Mining", "129",
	"Magic", "160",
        "PerformCommonTasks", "9103",
	"WeatherMagic", "161",
	"Scrying", "162",
	"Gatecraft", "163",
	"Artifacts", "164",
	"Necromancy", "165",
	"Imperial_City", "aa0m",
	"Aethelarn", "ap1t",
	"Cyrkarth", "bv26",
	"Newleaf", "ao9v",
	"Winewood", "ap1n",
	"Falstaff", "x1x",
	"Hal", "y1y",
	"HMSBounty", "ab3c"
);

LINE:
while ($line = <>) {
	if ($line =~/(\s*)([^#]*)#(.*)/) {
		$indent = $1;
		$line = $2;
		$comment = $3;
	} elsif ($line =~/(\s*)/) {
		$indent = $1;
		$comment = "";
	}
	if ($line =~/(\w+)/) {
		$command = $1;
	} else {
		next LINE;
	}
	print "$indent$1 ";
	$line =~ s/$command\s*//;
	$trcomment = "";
	while ($line =~ /(\S+)/) {
		if ($translation{$1}) {
			print "$translation{$1} ";
			if ($trcomment) {$trcomment = $trcomment. ", ";}
			$trcomment = $trcomment."$1";
		} else {print "$1 ";}
		$line =~ s/$1\s*//;
	}
	if ($trcomment . $comment) {
		if ($trcomment) {$trcomment.".";}
		print "# $trcomment $comment\n"
	} else {
		print "\n"
	}
}

